==> fop2-2.24-debian-x86_64.tgz: fop2/html/js/lang_el.js <==

lang['incoming_call']      = 'Εισερχομενη κληση';
lang['connecting_server']  = 'Συνδεση με server, προσπαθεια  ';

lang['from_queue']         = "Απο ουρα:";
lang['number']             = "Αριθμος:";
lang['name']               = "Ονομα:";

lang['dial']               = 'Κληση';
lang['transfer_vmail']     = 'Μεταφορα σto Ταχυδρομειο';
lang['transfer_external']  = 'Μεταφορα στο Κινητο';
lang['attendant_transfer'] = 'Μεταφορα';
lang['spy']                = 'Ακροαση';
lang['whisper']            = 'Ψιθυορς';
lang['pickup']             = "Ληψη κλησης";
lang['hangup']             = 'Αποσυνδεση';
lang['filter']             = 'Φιλτρο';

lang['enter_sec_code']     = 'Πληροφοριες συνδεσης';
lang['exten']              = 'Εσωτερικο:';
lang['password']           = 'Password:';

lang['confirm_hangup']     = 'Να αποσυνδεθει';
lang['areyousure']         = 'Ειστε σιγουρος?';
lang['yes']                = 'Ναι';
lang['no']                 = 'Οχι';

lang['paused']             = 'Παυση';
lang['set_information']    = 'Ρυθμιση πληροφοριας';
lang['member_of']          = 'Μελος του ';
lang['not_available']      = 'Το συστημα δεν ειναι διαθεσιμο αυτη τη στιγμη';
lang['not_connect']        = 'Αδυναμια συνδεσης σε server';
lang['one_moment']         = 'Μισο λεπτο παρακαλω';
lang['no_results']         = 'Δεν βρεθηκαν αποτελεσματα';

lang['toggle_lock']        = 'Κλειδωμα/Ανοιγμα Διασκεψης';
lang['toggle_muteall']     = 'Φιμωση ολων των Χρηστων';
lang['available']          = 'Διαθεσιμο';
lang['phonebook']          = 'Τηλεφ.Καταλογος';
lang['toggle_mute']        = 'Αλλαγη καταστασης φιμωσης';
lang['kick']               = 'Αποβολη Χρηστη';
lang['record']             = 'Ηχογραφηση κλησης';
lang['presence_noti']      = 'Ειδοποιηση Παρουσιας';

lang['queues']             = 'Ουρες';
lang['extensions']         = 'Εσωτερικα';
lang['trunks']             = 'Trunks';
lang['conferences']        = 'Διασκεψεις';
lang['other']              = 'Αλλα';
lang['enter_state']        = 'Εισαγωγη Τιμης';
lang['parkingslots']       = 'Θεσεις parking';
lang['ringgroups']         = 'Ομαδες Κουδουνισμου';

lang['enter_reg_code']     = 'Εισαγωγη κωδικου εγγραφης:';
lang['reg_code']     = 'Κωδικος Εγγραφης:';
lang['reg_name']     = 'Ονομα Εγγραφης:';

lang['remove_member']      = 'Αφαιρεση Μελους';
lang['remove_member_from'] = 'Αφαιρεση Απο ';
lang['pause_member']       = 'Παυση Μελους';
lang['unpause_member']     = 'Μη Παυση Μελους';
lang['add_member']         = 'Προσθηκη σε ';
lang['pickup_call']        = 'Αναληψη κλησης';
lang['email_user']         = 'Αποστολη email';
lang['send_sms']           = 'Αποστολη SMS';
lang['message']            = 'Mηνυμα:';
lang['sending']            = 'Αποστολη...';
lang['noResponse']         = 'Μη απαντηση.';

lang['chat']               = 'Chat';
lang['notlogged']          = 'Χρηστης Μη διαθεσιμος.';
lang['me']                 = 'Εγω';
lang['clearchat']          = 'Καθαρισμος Chat';
lang['note']               = 'Σημειωση';
lang['toggle_sound']       = 'Αλλαγη Ηχου';
lang['says']               = 'Λεει';

lang['agents']             = 'Agents: %d';
lang['calls']              = 'Κλησεις σε αναμονη: %d';
lang['call_connected']     = 'Συνομιλια με';
lang['changeDisplayType']  = 'Αλλαγη τροπου εμφανισης';

lang['voicemail']          = 'Φωνητικο Ταχυδρομειο';
lang['vmail_new']          = 'Νεο';
lang['vmail_old']          = 'Παλιο';
lang['vmail_work']         = 'Εργασια';
lang['vmail_family']       = 'Οικογενεια';
lang['vmail_friends']      = 'Φιλοι';
lang['vmail_number']       = 'Αριθμος.';
lang['vmail_date']         = 'Ημερομηνια';
lang['vmail_callerid']     = 'Αρ.Κλησης';
lang['vmail_duration']     = 'Διαρκεια';

lang['preferences']        = 'Προτιμησεις';
lang['summary']            = 'Περιληψη';
lang['detailed']           = 'Αναλυτικα';

lang['inactive_line']      = 'Καναλι %d ΜΗ ενεργο';
lang['inuse']              = '%d καναλια σε χρηση';
lang['vmail_count']        = 'Νεα %d, Παλια %d';
lang['logout']             = 'Εξοδος';

lang['NOTONLINE']          = 'Χρηστης εκτος συνδεσης';
lang['NOWONLINE']          = 'Χρηστης Συνδεδεμενος';

lang['prefSounds']         = 'Ηχοι';
lang['prefDisplay']        = 'Εμφανιση';

lang['labelSoundChat']     = 'Ηχοι Chat';
lang['labelSoundQueue']    = 'Ηχοι Ουρας';
lang['labelSoundRing']     = 'Ηχοι κλησης';

lang['labelDisplayQueue']          = 'Βασικη εμφανιση ουρας:';
lang['labelDisplayDynamicLine']    = 'Δυναμικη εμφανιση καταστασης:';
lang['labelDisplayNotifyDuration'] = 'Ενημερωση Διαρκειας:';
lang['labelDisplayLanguage']       = 'Γλωσσα:';

// Internationalization strings DATE
dateFormat.i18n = {
	dayNames: [
		"Κυρ", "Δευ", "Τρι", "Τετ", "Πεμ", "Παρ", "Σαβ",
		"Κυριακη", "Δευτερα", "Τριτη", "Τεταρτη", "Πεμπτη", "Παρασκευη", "Σαββατο"
	],
	monthNames: [
		"Ιαν", "Φεβ", "Μαρ", "Απρ", "Μαι", "Ιου", "Ιολ", "Αυγ", "Σεπ", "Οκτ", "Νοε", "Δεκ",
		"Ιανουαριος", "Φεβρουαριος", "Μαρτιος", "Απριλιος", "Μαιος", "Ιουνιος", "Ιουλιος", "Αυγουστος", "Σεπτεμβριος", "Oκτωβριος", "Νοεμβριος", "Δεκεμβριος"
	]
};

==> fop2-2.29.03-debian-x86_64.tgz: fop2/html/js/lang_el.js <==

lang['incoming_call']      = 'Εισερχομενη κληση';
lang['connecting_server']  = 'Συνδεση με server, προσπαθεια  ';

lang['from_queue']         = "Απο ουρα:";
lang['number']             = "Αριθμος:";
lang['name']               = "Ονομα:";

lang['dial']               = 'Κληση';
lang['transfer_vmail']     = 'Μεταφορα σto Ταχυδρομειο';
lang['transfer_external']  = 'Μεταφορα στο Κινητο';
lang['attendant_transfer'] = 'Μεταφορα';
lang['blind_transfer']     = 'τυφλή Μεταφορα';
lang['spy']                = 'Ακροαση';
lang['whisper']            = 'Ψιθυορς';
lang['pickup']             = "Ληψη κλησης";
lang['hangup']             = 'Αποσυνδεση';
lang['filter']             = 'Φιλτρο';

lang['enter_sec_code']     = 'Πληροφοριες συνδεσης';
lang['exten']              = 'Εσωτερικο:';
lang['password']           = 'Password:';

lang['confirm_hangup']     = 'Να αποσυνδεθει';
lang['areyousure']         = 'Ειστε σιγουρος?';
lang['yes']                = 'Ναι';
lang['no']                 = 'Οχι';
lang['cancel']             = 'Aκύρωση';
lang['accept']             = 'Aποδέχομαι';

lang['paused']             = 'Παυση';
lang['set_information']    = 'Ρυθμιση πληροφοριας';
lang['set_penalty']        = 'ποινή';
lang['member_of']          = 'Μελος του ';
lang['not_available']      = 'Το συστημα δεν ειναι διαθεσιμο αυτη τη στιγμη';
lang['not_connect']        = 'Αδυναμια συνδεσης σε server';
lang['one_moment']         = 'Μισο λεπτο παρακαλω';
lang['no_results']         = 'Δεν βρεθηκαν αποτελεσματα';

lang['toggle_lock']        = 'Κλειδωμα/Ανοιγμα Διασκεψης';
lang['toggle_muteall']     = 'Φιμωση ολων των Χρηστων';
lang['available']          = 'Διαθεσιμο';
lang['phonebook']          = 'Τηλεφ.Καταλογος';
lang['toggle_mute']        = 'Αλλαγη καταστασης φιμωσης';
lang['kick']               = 'Αποβολη Χρηστη';
lang['record']             = 'Ηχογραφηση κλησης';
lang['presence_noti']      = 'Ειδοποιηση Παρουσιας';

lang['queues']             = 'Ουρες';
lang['extensions']         = 'Εσωτερικα';
lang['trunks']             = 'Trunks';
lang['conferences']        = 'Διασκεψεις';
lang['other']              = 'Αλλα';
lang['enter_state']        = 'Εισαγωγη Τιμης';
lang['parkingslots']       = 'Θεσεις parking';
lang['ringgroups']         = 'Ομαδες Κουδουνισμου';

lang['enter_reg_code']     = 'Εισαγωγη κωδικου εγγραφης:';
lang['reg_code']     = 'Κωδικος Εγγραφης:';
lang['reg_name']     = 'Ονομα Εγγραφης:';

lang['remove_member']      = 'Αφαιρεση Μελους';
lang['remove_member_from'] = 'Αφαιρεση Απο ';
lang['pause_member']       = 'Παυση Μελους';
lang['unpause_member']     = 'Μη Παυση Μελους';
lang['add_member']         = 'Προσθηκη σε ';
lang['pickup_call']        = 'Αναληψη κλησης';
lang['email_user']         = 'Αποστολη email';
lang['send_sms']           = 'Αποστολη SMS';
lang['message']            = 'Mηνυμα:';
lang['sending']            = 'Αποστολη...';
lang['noResponse']         = 'Μη απαντηση.';

lang['chat']               = 'Chat';
lang['notlogged']          = 'Χρηστης Μη διαθεσιμος.';
lang['calls_taken']        = 'Κλήσεις που λαμβάνονται:';
lang['penalty']            = 'Ποινή:';

lang['me']                 = 'Εγω';
lang['clearchat']          = 'Καθαρισμος Chat';
lang['note']               = 'Σημειωση';
lang['toggle_sound']       = 'Αλλαγη Ηχου';
lang['says']               = 'Λεει';

lang['agents']             = 'Agents: %d';
lang['calls']              = 'Κλησεις σε αναμονη: %d';
lang['call_connected']     = 'Συνομιλια με';
lang['changeDisplayType']  = 'Αλλαγη τροπου εμφανισης';

lang['voicemail']          = 'Φωνητικο Ταχυδρομειο';
lang['vmail_new']          = 'Νεο';
lang['vmail_old']          = 'Παλιο';
lang['vmail_work']         = 'Εργασια';
lang['vmail_family']       = 'Οικογενεια';
lang['vmail_friends']      = 'Φιλοι';
lang['vmail_number']       = 'Αριθμος.';
lang['vmail_date']         = 'Ημερομηνια';
lang['vmail_callerid']     = 'Αρ.Κλησης';
lang['vmail_duration']     = 'Διαρκεια';
lang['play']               = 'Παίζουν';
lang['download']           = 'Κατεβάστε';

lang['preferences']        = 'Προτιμησεις';
lang['summary']            = 'Περιληψη';
lang['detailed']           = 'Αναλυτικα';

lang['inactive_line']      = 'Καναλι %d ΜΗ ενεργο';
lang['inuse']              = '%d καναλια σε χρηση';
lang['vmail_count']        = 'Νεα %d, Παλια %d';
lang['logout']             = 'Εξοδος';

lang['NOTONLINE']          = 'Χρηστης εκτος συνδεσης';
lang['NOWONLINE']          = 'Χρηστης Συνδεδεμενος';

lang['prefSounds']         = 'Ηχοι';
lang['prefDisplay']        = 'Εμφανιση';
lang['prefPopup']          = 'Popup';
lang['prefPhone']          = 'Τοηλέφωνο';

lang['labelSoundChat']     = 'Ηχοι Chat';
lang['labelSoundQueue']    = 'Ηχοι Ουρας';
lang['labelSoundRing']     = 'Ηχοι κλησης';

lang['labelDisplayQueue']          = 'Βασικη εμφανιση ουρας';
lang['labelDisplayDynamicLine']    = 'Δυναμικη εμφανιση καταστασης';
lang['labelDisplayNotifyDuration'] = 'Ενημερωση Διαρκειας';
lang['labelDisplayLanguage']       = 'Γλωσσα';
lang['labelAutoPopup']             = 'Auto Popup';
lang['labelAutoAnswer']            = 'Δυτόματη Δπάντηση';

lang['close']                      = 'Κοντά';
lang['recordings']                 = 'Ηχογραφήσεις';
lang['cdrrecords']                 = 'ιστορικό κλήσεων';

// Internationalization strings DATE
dateFormat.i18n = {
	dayNames: [
		"Κυρ", "Δευ", "Τρι", "Τετ", "Πεμ", "Παρ", "Σαβ",
		"Κυριακη", "Δευτερα", "Τριτη", "Τεταρτη", "Πεμπτη", "Παρασκευη", "Σαββατο"
	],
	monthNames: [
		"Ιαν", "Φεβ", "Μαρ", "Απρ", "Μαι", "Ιου", "Ιολ", "Αυγ", "Σεπ", "Οκτ", "Νοε", "Δεκ",
		"Ιανουαριος", "Φεβρουαριος", "Μαρτιος", "Απριλιος", "Μαιος", "Ιουνιος", "Ιουλιος", "Αυγουστος", "Σεπτεμβριος", "Oκτωβριος", "Νοεμβριος", "Δεκεμβριος"
	]
};
